const db = require('../models');
const Utils = require('../utils');
// const { seq, DataTypes } = require('sequelize');

const Sequelize = db.Sequelize;
const Op = Sequelize.Op;
// const queryInterface = Sequelize.getQueryInterface();

module.exports = class PujaModelsSamagriMappingsDBApi {
  static async create(data, options) {
    const currentUser = (options && options.currentUser) || { id: null };
    const transaction = (options && options.transaction) || undefined;

    // const puja_model_samagri_mappings =
    //   await db.puja_model_samagri_mappings.create(
    //     {
    //       model_id: data.model_id || null,
    //       samagri_id: data.samagri_id || null,
    //       no_of_standard_qty: data.no_of_standard_qty || null,
    //       importHash: data.importHash || null,
    //       createdById: currentUser.id,
    //       updatedById: currentUser.id,
    //     },
    //     { transaction },
    //   );

    const puja_model_samagri_mappings =
      await db.puja_model_samagri_mappings.bulkCreate(data, {
        returning: true,
      });

    return puja_model_samagri_mappings;
  }

  static async findAll(filter, options) {
    var limit = filter.limit || 0;
    var offset = 0;
    const currentPage = +filter.page;

    offset = currentPage * limit;

    var orderBy = null;

    const transaction = (options && options.transaction) || undefined;
    let where = {};
    let include = [];

    if (filter) {
      if (filter.id) {
        where = {
          ...where,
          ['id']: Utils.uuid(filter.id),
        };
      }

      if (filter.name) {
        where = {
          ...where,
          [Op.and]: Utils.ilike('pujas', 'name', filter.name),
        };
      }

      if (filter.description) {
        where = {
          ...where,
          [Op.and]: Utils.ilike('pujas', 'description', filter.description),
        };
      }

      if (filter.duration_hrsRange) {
        const [start, end] = filter.duration_hrsRange;

        if (start !== undefined && start !== null && start !== '') {
          where = {
            ...where,
            duration_hrs: {
              ...where.duration_hrs,
              [Op.gte]: start,
            },
          };
        }

        if (end !== undefined && end !== null && end !== '') {
          where = {
            ...where,
            duration_hrs: {
              ...where.duration_hrs,
              [Op.lte]: end,
            },
          };
        }
      }

      if (
        filter.active === true ||
        filter.active === 'true' ||
        filter.active === false ||
        filter.active === 'false'
      ) {
        where = {
          ...where,
          active: filter.active === true || filter.active === 'true',
        };
      }

      if (filter.language) {
        where = {
          ...where,
          language: filter.language,
        };
      }

      if (filter.createdAtRange) {
        const [start, end] = filter.createdAtRange;

        if (start !== undefined && start !== null && start !== '') {
          where = {
            ...where,
            ['createdAt']: {
              ...where.createdAt,
              [Op.gte]: start,
            },
          };
        }

        if (end !== undefined && end !== null && end !== '') {
          where = {
            ...where,
            ['createdAt']: {
              ...where.createdAt,
              [Op.lte]: end,
            },
          };
        }
      }
    }

    let { rows, count } = await db.puja_model_samagri_mappings.findAndCountAll({
      where,
      include,
      distinct: true,
      limit: limit ? Number(limit) : undefined,
      offset: offset ? Number(offset) : undefined,
      // order:
      //   filter.field && filter.sort
      //     ? [[filter.field, filter.sort]]
      //     : [['createdAt', 'desc']],
      transaction,
    });

    //    rows = await this._fillWithRelationsAndFilesForRows(
    //      rows,
    //      options,
    //    );

    return { rows, count };
  }

  static async findBy(where, options) {
    const transaction = (options && options.transaction) || undefined;

    const puja_model_samagri_mappings =
      await db.puja_model_samagri_mappings.findOne({ where }, { transaction });

    if (!puja_model_samagri_mappings) {
      return puja_model_samagri_mappings;
    }

    const output = puja_model_samagri_mappings.get({ plain: true });

    return output;
  }

  static async update(data, options) {
    const currentUser = (options && options.currentUser) || { id: null };
    const transaction = (options && options.transaction) || undefined;

    // const puja_model_samagri_mappings =
    //   await db.puja_model_samagri_mappings.findByPk(id, {
    //     transaction,
    //   });

    // await puja_model_samagri_mappings.update(
    //   {
    //     model_id: data.model_id || null,
    //     samagri_id: data.samagri_id || null,
    //     no_of_standard_qty: data.no_of_standard_qty || null,
    //   },
    //   { transaction },
    // );

    const puja_model_samagri_mappings = await Promise.all(
      data.map(async (item) => {
        return await db.puja_model_samagri_mappings.update(
          {
            model_id: item.model_id,
            samagri_id: item.samagri_id,
            no_of_standard_qty: item.no_of_standard_qty,
            isProvidedBy: item.isProvidedBy,
          },
          { where: { id: item.id } },
        );
      }),
    );

    return true;
  }

  static async remove(data, options) {
    const currentUser = (options && options.currentUser) || { id: null };
    const transaction = (options && options.transaction) || undefined;


    // const puja_model_samagri_mappings =
    //   await db.puja_model_samagri_mappings.findByPk(id, options);

    // await db.puja_model_samagri_mappings.destroy({
    //   where: { id },
    // });

    // db.puja_model_samagri_mappings
    //   .destroy({
    //     where: {
    //       id: 222,
    //     },
    //   })
    //   .then((rowsDeleted) => {
    //     console.log(`Deleted ${rowsDeleted} rows`);
    //   })
    //   .catch((error) => {
    //     console.error(`error was ${error}`);
    //   });

    // db.puja_model_samagri_mappings.destroy({
    //   where: {
    //     id: [222, 223],
    //   },
    // });

    const deletedRows = await db.puja_model_samagri_mappings.destroy({
      where: { id: data },
      force: true,
    });

    return deletedRows;
  }
};
