const config = require('../../config');
const providers = config.providers;
const crypto = require('crypto');
const bcrypt = require('bcrypt');
const moment = require('moment');

module.exports = function (sequelize, DataTypes) {
  const bookings = sequelize.define(
    'bookings',
    {
      id: {
        type: DataTypes.INTEGER,
        unique: true,
        primaryKey: true,
        autoIncrement: true,
      },

      user_id: {
        type: DataTypes.TEXT,
      },

      pujari_id: {
        type: DataTypes.INTEGER,
      },

      puja_id: {
        type: DataTypes.INTEGER,
      },

      pujari_karishye_notes: {
        type: DataTypes.TEXT,
      },
      pujari_customer_notes: {
        type: DataTypes.TEXT,
      },
      customer_notes: {
        type: DataTypes.TEXT,
      },

      price: {
        type: DataTypes.INTEGER,
      },

      event_type: {
        type: DataTypes.ENUM,

        values: ['remote', 'at_my_home', 'near_my_home', 'on_behalf'],
      },

      model: {
        type: DataTypes.INTEGER,
      },

      address: {
        type: DataTypes.TEXT,
      },
      address_latitude: {
        type: DataTypes.INTEGER
      },
      address_longitude: {
        type: DataTypes.INTEGER
      },

      start_date: {
        type: DataTypes.DATE,
      },

      end_date: {
        type: DataTypes.DATE,
      },
      muhurat: {
        type: DataTypes.DATE,
      },
      muhurtam: {
        type: DataTypes.DATE,
      },
      start_time: {
        type: DataTypes.DATE,
      },
      end_time: {
        type: DataTypes.DATE,
      },
      no_of_pujaris: {
        type: DataTypes.INTEGER,
      },

      duration_hrs: {
        type: DataTypes.INTEGER,
      },

      booking_status: {
        type: DataTypes.ENUM,

        values: [
          'submitted',
          'pujari_assigned',
          'pujari_accepted',
          'pujari_rejected',
          'plan_under_review',
          'plan_approved',
          'puja_started',
          'puja_ended',
          'pujari_amount_credited',
          'puja_confirmed'
        ],
      },
      state: {
        type: DataTypes.ENUM,
        values: [
          'active', 'suspended', 'completed', 'cancelled'
        ]
      },
      samagri_status: {
        type: DataTypes.ENUM,
        values: ['none', 'samagri_under_review', 'procured', 'packed', 'on_the_way', 'delivered']
      },
      payment_status: {
        type: DataTypes.ENUM,
        values: ['pending', 'partial', 'completed', 'refunded'],
      },


      base_price: {
        type: DataTypes.INTEGER,
      },

      final_price: {
        type: DataTypes.INTEGER,
      },

      pujari_cost: {
        type: DataTypes.INTEGER,
      },
      booking_selling_price: {
        type: DataTypes.INTEGER,
      },
      gst: {
        type: DataTypes.INTEGER,
      },
      service_fee: {
        type: DataTypes.INTEGER,
      },
      user_feedback: {
        type: DataTypes.TEXT
      },


      status: {
        type: DataTypes.ENUM,

        values: [
          'under review',

          'pending payment',

          'confirmed',

          'material dispatched',

          'completed',

          'suspended',

          'cancelled',
        ],
      },

      importHash: {
        type: DataTypes.STRING(255),
        allowNull: true,
        unique: true,
      },
    },
    {
      timestamps: true,
      paranoid: true,
      freezeTableName: true,
    },

  );

  bookings.associate = (db) => {
    db.bookings.belongsTo(db.users, {
      as: 'createdBy',
    });

    db.bookings.belongsTo(db.users, {
      as: 'updatedBy',
    });
  };

  return bookings;
};
