const express = require('express');

const UsersDBApi = require('../db/api/users');
const KarusersDBApi = require('../db/api/karusers');
const Booking_participantsDBApi = require('../db/api/booking_participants');
const PujarisDBApi = require('../db/api/pujaris');
const Pujari_applicationsDBApi = require('../db/api/pujari_applications');
const PujasDBApi = require('../db/api/pujas');
const Puja_samagri_mappingsDBApi = require('../db/api/puja_samagri_mappings');
const SamagriDBApi = require('../db/api/samagri');
const Booking_samagri_mappingsDBApi = require('../db/api/booking_samagri_mappings');
const BookingsDBApi = require('../db/api/bookings');
const PujaProceduresDBApi = require('../db/api/puja_procedures');
const PujaModelsDBApi = require('../db/api/puja_models');
const Puja_models_procedure_mappingsDBApi = require('../db/api/puja_models_procedure_mappings');
const Puja_models_samagri_mappingsDBApi = require('../db/api/puja_models_samagri_mappings');
const db = require('../db/models');

const wrapAsync = require('../helpers').wrapAsync;

const router = express.Router();


/**
 *  @swagger
 *  /api/utility:
 *    get:
 *      security:
 *        - bearerAuth: []
 *      tags: [All Data]
 *      summary: Get all data 
 *      description: Get all data
 *      responses:
 *        200:
 *          description: All data successfully received
 *          content:
 *            application/json:
 *              schema:
 *                type: array
 *                items:
 *                  $ref: "#/components/schemas/Pujas"
 *        401:
 *          $ref: "#/components/responses/UnauthorizedError"
 *        404:
 *          description: Data not found
 *        500:
 *          description: Some server error
 */


router.get(
  '/',
  wrapAsync(async (req, res) => {

    // users
    const usersPayload = await UsersDBApi.findAll(req.query);
    const usersCount = usersPayload["count"];

    // karusers
    const karUsersPayload = await KarusersDBApi.findAll(req.query);
    const karUsersCount = karUsersPayload["count"];

    // bookingApplications
    const bookingApplicationsPayload = await Booking_participantsDBApi.findAll(req.query);
    const bookingApplicationsCount = bookingApplicationsPayload["count"];

    // bookingApplications
    const pujarisPayload = await PujarisDBApi.findAll(req.query);
    const pujarisCount = pujarisPayload["count"];

    // pujari applications
    const pujariApplicationsPayload = await Pujari_applicationsDBApi.findAll(req.query);
    const pujariApplicationsCount = pujariApplicationsPayload["count"];

    // pujas
    const pujasPayload = await PujasDBApi.findAll(req.query);
    const pujasCount = pujasPayload["count"];

    // puja samagri mappings 
    const pujaSamagriMappingsPayload = await Puja_samagri_mappingsDBApi.findAll(req.query);
    const pujaSamagriMappingsCount = pujaSamagriMappingsPayload["count"];

    // samagri
    const samagriPayload = await SamagriDBApi.findAll(req.query);
    const samagriCount = samagriPayload["count"];

    // booking samagri mappings 
    const bookingSamagriMappingsPayload = await Booking_samagri_mappingsDBApi.findAll(req.query);
    const bookingSamagriCount = bookingSamagriMappingsPayload["count"];

    // bookings
    const bookingsPayload = await BookingsDBApi.findAll(req.query);;
    const bookingsCount = bookingsPayload["count"];

    // procedures 
    const proceduresPayload = await PujaProceduresDBApi.findAll(req.query);
    const proceduresCount = proceduresPayload["count"];

    // puja models 
    const pujaModelsResponse = await PujaModelsDBApi.findAll(req.query);
    const pujaModelsCount = pujaModelsResponse["count"];

    // puja model procedure mappings
    const pujaModelProcedureMappingsResponse = await Puja_models_procedure_mappingsDBApi.findAll(req.query);
    const pujaModelProcedureMappingsCount = pujaModelProcedureMappingsResponse["count"];

    // puja model procedure mappings
    const pujaModelSamagriMappingsResponse = await Puja_models_samagri_mappingsDBApi.findAll(req.query);
    const pujaModelSamagriMappingsCount = pujaModelSamagriMappingsResponse["count"];

    const response = {
      "usersCount": usersCount,
      "karUsersCount": karUsersCount,
      "bookingApplicationsCount": bookingApplicationsCount,
      "pujarisCount": pujarisCount,
      "pujariApplicationsCount": pujariApplicationsCount,
      "pujasCount": pujasCount,
      "pujaSamagriMappingsCount": pujaSamagriMappingsCount,
      "samagriCount": samagriCount,
      "bookingSamagriCount": bookingSamagriCount,
      "bookingsCount": bookingsCount,
      "proceduresCount": proceduresCount,
      "pujaModelsCount": pujaModelsCount,
      "pujaModelProcedureMappingsCount": pujaModelProcedureMappingsCount,
      "pujaModelSamagriMappingsCount": pujaModelSamagriMappingsCount,
    }


    res.status(200).send(response);
  }),
);

module.exports = router;
