const db = require('../db/models');
const UsersDBApi = require('../db/api/users');

const InvitationEmail = require('./email/list/invitation');
const ValidationError = require('./notifications/errors/validation');
const AuthService = require('./auth');
const EmailSender = require('./email');
const WatiService = require('../services/wati');

module.exports = class UsersService {
  static async create(data, currentUser, sendInvitationEmails = true, host) {
    let transaction = await db.sequelize.transaction();
    let email = data.email;
    let emailsToInvite = [];
    try {
      if (email) {
        let user = await UsersDBApi.findBy({ email }, { transaction });
        if (user) {
          throw new ValidationError('iam.errors.userAlreadyExists');
        } else {
          await UsersDBApi.create(
            { data },
            {
              currentUser,
              transaction,
            },
          );
          emailsToInvite.push(email);
          const mailSender = new EmailSender();
          try {
            await mailSender.sendEmail({
              dynamicData: {},
              mailProps: { to: mailSender.adminMail },
              template: mailSender.htmlTemplates.NEW_USER__ADMIN
            });
            // await mailSender.sendEmail({
            //   dynamicData: {},
            //   mailProps: { to: data.email },
            //   template:mailSender.htmlTemplates.NEW_USER__USER
            // });

            const watiObj = new WatiService();
            WatiService.sendWhatsappMessage(
              data.phoneNumber,
              watiObj.templates.userCreated,
            );
            // WatiService.sendWhatsappMessage(
            //   watiObj.adminPhone,
            //   watiObj.templates.userCreatedAdmin,
            //   [{
            //     "name": "user_name",
            //     "value": `${data.firstName} ${data.lastName}`
            //   }]
            // )
          } catch (error) {
            console.log("error", error)
          }
        }
      }
      await transaction.commit();
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
    if (emailsToInvite && emailsToInvite.length) {
      if (!sendInvitationEmails) {
        return;
      }
      // AuthService.sendPasswordResetEmail(email, 'invitation', host);
    }
  }

  static async update(data, id, currentUser) {
    const transaction = await db.sequelize.transaction();
    try {
      let users = await UsersDBApi.findBy({ id }, { transaction });

      if (!users) {
        throw new ValidationError('iam.errors.userNotFound');
      }

      await UsersDBApi.update(id, data, {
        currentUser,
        transaction,
      });
      try {
        const watiObj = new WatiService();
        // WatiService.sendWhatsappMessage(
        //   watiObj.adminPhone,
        //   watiObj.templates.userCreatedAdmin,
        //   [{
        //     "name": "user_name",
        //     "value": `${data.firstName} ${data.lastName}`
        //   }]
        // );
        const mailSender = new EmailSender();

        await mailSender.sendEmail({
          dynamicData: {},
          mailProps: { to: data.email },
          template: mailSender.htmlTemplates.EDIT_USER__ADMIN
        });
      } catch (error) {
        console.log("error", error)
      }

      await transaction.commit();
      return users;
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async remove(id, currentUser) {
    const transaction = await db.sequelize.transaction();

    try {
      if (currentUser.id === id) {
        throw new ValidationError('iam.errors.deletingHimself');
      }

      if (currentUser.role !== 'admin') {
        throw new ValidationError('errors.forbidden.message');
      }

      await UsersDBApi.remove(id, {
        currentUser,
        transaction,
      });

      await transaction.commit();
      return { message: 'success' };
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async getUserDetails(id) {
    try {
      const result = await UsersDBApi.findBy({ id: id });
      console.log("result --- booking", result);
      return result;
    } catch (error) {
      throw error;
    }
  }
};
